Index: src/gpu/gl/GrGLProgramDesc.h |
diff --git a/src/gpu/gl/GrGLProgramDesc.h b/src/gpu/gl/GrGLProgramDesc.h |
index b1f54b7e29280e3ad201939541725be551cc281c..e91dbe0950716514e52389a5474843ae403dfe19 100644 |
--- a/src/gpu/gl/GrGLProgramDesc.h |
+++ b/src/gpu/gl/GrGLProgramDesc.h |
@@ -55,15 +55,13 @@ public: |
int currAttribIndex); |
/** |
* Builds a program descriptor from a GrDrawState. Whether the primitive type is points, the |
* output of GrDrawState::getBlendOpts, and the caps of the GrGpuGL are also inputs. It also |
* outputs the color and coverage stages referenced by the generated descriptor. This may |
* not contain all stages from the draw state and coverage stages from the drawState may |
* be treated as color stages in the output. |
*/ |
- static bool Build(const GrDrawState&, |
+ static bool Build(const GrOptDrawState&, |
GrGpu::DrawType drawType, |
- GrDrawState::BlendOptFlags, |
GrBlendCoeff srcCoeff, |
GrBlendCoeff dstCoeff, |
const GrGpuGL* gpu, |
@@ -55,15 +55,13 @@ public: |
int currAttribIndex); |
/** |
- * Builds a program descriptor from a GrDrawState. Whether the primitive type is points, the |
- * output of GrDrawState::getBlendOpts, and the caps of the GrGpuGL are also inputs. It also |
- * outputs the color and coverage stages referenced by the generated descriptor. This may |
- * not contain all stages from the draw state and coverage stages from the drawState may |
- * be treated as color stages in the output. |
+ * Builds a program descriptor from a GrOptDrawState. Whether the primitive type is points, and |
+ * the caps of the GrGpuGL are also inputs. It also outputs the color and coverage stages |
+ * referenced by the generated descriptor. Coverage stages from the drawState may be treated as |
+ * color stages in the output. |
*/ |